tinda
.  
.
.
#
Buggy Sub-Alpha stage.
.
.
.

# Usage:
from tinda import *
.# doing that will enable you to use all functions as they come.
bot()
.# bot lists all the available functions and speaks a few generic things.

.from tinda import linkDownloader
.linkDownloader('link')
.# or a function can be imported seperately


Developed by Hank Singh (c)
© 2021 SINGHINDUSTRIES.

